import { CorsignPayload, CorsignToken } from './token';
export interface GenerateSignedCorsignTokenResponse {
    /**
     * Encoded Corsign-JWT
     */
    value: string;
    /**
     * Info message
     */
    info?: string;
    /**
     * QRCode Data URI
     */
    qr: string;
    /**
     * Wether or not the confirmation email was sent successfully.
     */
    emailSendSuccessful?: boolean;
    /**
     * Might contain error message for why the email wasn't sent
     */
    emailSendError?: string;
    /**
     * Wether or not manual transmission of positive test cases is required.
     */
    requireManualSendOfPositive: boolean;
}
/**
 *
 * @param payload The payload for the Corsign-Token
 * @param signerToken
 * @param tokenId
 * @param apiUrl
 * @returns Encoded Token and QRCode {@link GenerateSignedCorsignTokenResponse}
 */
export declare const generateSignedCorsignToken: (payload: CorsignPayload, signerToken: string, tokenId: string, apiUrl?: string) => Promise<GenerateSignedCorsignTokenResponse>;
/**
 *
 * @param token Encoded Corsign-JWT
 * @param apiUrl
 * @returns Decoded ({@link CorsignToken}) if successfull
 * @returns reject with status 410 if token is valid but expired
 * @returns reject with status 400 if token is invalid
 */
export declare const validateCorsignToken: (token: string, apiUrl?: string) => Promise<CorsignToken>;
